<?php

namespace Drupal\zotero_citeproc_js\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * The settings form.
 *
 * @package Drupal\zotero_citeproc_js\Form
 */
class SettingsForm extends ConfigFormBase {

  /**
   * {@inheritDoc}
   */
  protected function getEditableConfigNames() {
    return ['zotero_citeproc_js.settings'];
  }

  /**
   * {@inheritDoc}
   */
  public function getFormId() {
    return 'settings_form';
  }

  /**
   * {@inheritDoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('zotero_citeproc_js.settings');

    $form['actions']['#type'] = 'actions';

    $form['url'] = [
      '#type' => 'url',
      '#title' => $this->t('URL'),
      '#default_value' => $config->get('url'),
      '#description' => $this->t('URL to the Zotero CiteProc JS server'),
    ];

    $form['timeout'] = [
      '#type' => 'number',
      '#step' => 0.01,
      '#title' => $this->t('Timeout'),
      '#default_value' => $config->get('timeout'),
      '#description' => $this->t("The maximum time in seconds to wait for a request to complete. 0 means wait indefinitely."),
    ];

    $form['actions']['submit'] = [
      '#type' => 'submit',
      '#value' => $this->t('Save configuration'),
      '#button_type' => 'primary',
    ];

    $form['#theme'] = 'system_config_form';

    return $form;
  }

  /**
   * {@inheritDoc}
   *
   * @throws \Drupal\Core\Config\ConfigValueException
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $config = $this->config('zotero_citeproc_js.settings');
    $config->set('url', $form_state->getValue('url'));
    $config->set('timeout', $form_state->getValue('timeout'));
    $config->save();
    parent::submitForm($form, $form_state);
  }

}
